@@ -76,9 +76,12 @@ void track_break_rename();
 void wavbreaker_write_files(char *dirname);
 GtkWidget *wavbreaker_get_main_window();
 gboolean open_file_arg( gpointer data);
-
+void track_break_add_offset( char* filename, guint offset);
+void track_break_clear_list();
 void wavbreaker_quit();
 
+extern char *sample_filename;
+
 #define MB_OVL_MOODBAR 2
 #define MB_OVL_WAVEFORM 7
 #define MOODBAR_BLEND(waveform,moodbar) (((MB_OVL_WAVEFORM*waveform+MB_OVL_MOODBAR*moodbar))/(MB_OVL_MOODBAR+MB_OVL_WAVEFORM))
